==> apache-cloudstack-4.19.2.0-src.tar.bz2: apache-cloudstack-4.19.2.0-src/engine/api/src/main/java/org/apache/cloudstack/storage/object/ObjectStoreEntity.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cloudstack.storage.object;

import org.apache.cloudstack.engine.subsystem.api.storage.DataStore;

import java.util.List;
import java.util.Map;

public interface ObjectStoreEntity extends DataStore, ObjectStore {
    Bucket createBucket(Bucket bucket, boolean objectLock);

    List<Bucket> listBuckets();

    boolean createUser(long accountId);

    boolean deleteBucket(String name);

    boolean setBucketEncryption(String name);

    boolean deleteBucketEncryption(String name);

    boolean setBucketVersioning(String name);

    boolean deleteBucketVersioning(String name);

    void setBucketPolicy(String name, String policy);

    void setQuota(String name, int quota);

    Map<String, Long> getAllBucketsUsage();
}

==> apache-cloudstack-4.20.1.0-src.tar.bz2: apache-cloudstack-4.20.1.0-src/engine/api/src/main/java/org/apache/cloudstack/storage/object/ObjectStoreEntity.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cloudstack.storage.object;

import com.cloud.agent.api.to.BucketTO;
import org.apache.cloudstack.engine.subsystem.api.storage.DataStore;

import java.util.List;
import java.util.Map;

public interface ObjectStoreEntity extends DataStore, ObjectStore {
    Bucket createBucket(Bucket bucket, boolean objectLock);

    List<Bucket> listBuckets();

    boolean createUser(long accountId);

    boolean deleteBucket(BucketTO bucket);

    boolean setBucketEncryption(BucketTO bucket);

    boolean deleteBucketEncryption(BucketTO bucket);

    boolean setBucketVersioning(BucketTO bucket);

    boolean deleteBucketVersioning(BucketTO bucket);

    void setBucketPolicy(BucketTO bucket, String policy);

    void setQuota(BucketTO bucket, int quota);

    Map<String, Long> getAllBucketsUsage();
}
